@@ -18,7 +18,7 @@ import (
 	"github.com/urfave/cli/v2"
 	gcfg "gopkg.in/gcfg.v1"
 	lumberjack "gopkg.in/natefinch/lumberjack.v2"
-	"k8s.io/klog"
+	"k8s.io/klog/v2"
 
 	kexec "k8s.io/utils/exec"
 	utilnet "k8s.io/utils/net"
